@@ -58,19 +58,37 @@ class SENSORS_EXPORT SensorDataModel : public QAbstractTableModel, public QQmlPa
      * Should this model be updated or not. Defaults to true.
      */
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
+    /**
+     * Is this model ready?
+     *
+     * Ready means it has retrieved the metadata for the sensors specified in
+     * \ref sensors.
+     */
+    Q_PROPERTY(bool ready READ isReady NOTIFY readyChanged)
+
+    /**
+     * Used by the model to provide data for the Color role if set.
+     */
+    Q_PROPERTY(QVariantMap sensorColors READ sensorColors WRITE setSensorColors NOTIFY sensorColorsChanged)
 
 public:
+    /**
+     * The roles that this model exposes
+     * @see Sensor
+     */
     enum AdditionalRoles {
-        SensorId = Qt::UserRole + 1, //< The backend path to the sensor.
-        Name,                        //< The name of the sensor.
-        ShortName,                   //< A shorter name for the sensor. This is equal to name if not set.
-        Description,                 //< A description for the sensor.
-        Unit,                        //< The unit of the sensor.
-        Minimum,                     //< The minimum value this sensor can have.
-        Maximum,                     //< The maximum value this sensor can have.
-        Type,                        //< The QVariant::Type of the sensor.
-        Value,                       //< The value of the sensor.
-        FormattedValue,              //< A formatted string of the value of the sensor.
+        SensorId = Qt::UserRole + 1, ///< The backend path to the sensor.
+        Name,                        ///< The name of the sensor.
+        ShortName,                   ///< A shorter name for the sensor. This is equal to name if not set.
+        Description,                 ///< A description for the sensor.
+        Unit,                        ///< The unit of the sensor.
+        Minimum,                     ///< The minimum value this sensor can have.
+        Maximum,                     ///< The maximum value this sensor can have.
+        Type,                        ///< The QVariant::Type of the sensor.
+        Value,                       ///< The value of the sensor.
+        FormattedValue,              ///< A formatted string of the value of the sensor.
+        Color,                       ///< A color of the sensor, if sensorColors is set
+        UpdateInterval,              ///< The time in milliseconds between each update of the sensor.
     };
     Q_ENUM(AdditionalRoles)
 
@@ -97,6 +115,13 @@ public:
     qreal minimum() const;
     qreal maximum() const;
 
+    QVariantMap sensorColors() const;
+    void setSensorColors(const QVariantMap &sensorColors);
+    Q_SIGNAL void sensorColorsChanged();
+
+    bool isReady() const;
+    Q_SIGNAL void readyChanged();
+
     Q_INVOKABLE void addSensor(const QString &sensorId);
     Q_INVOKABLE void removeSensor(const QString &sensorId);
     Q_INVOKABLE int column(const QString &sensorId) const;
